@@ -14,13 +14,14 @@
 #    under the License.
 
 import os
+from unittest import mock
 
 import ddt
-import mock
 import requests
 
 from rally.common import cfg
 from rally import exceptions
+
 from rally_openstack.verification.tempest import config
 from rally_openstack.verification.tempest import context
 from tests.unit import fakes
@@ -43,6 +44,7 @@ CRED = {
     "project_domain_name": "admin"
 }
 
+NET_PATH = "rally_openstack.common.services.network"
 PATH = "rally_openstack.verification.tempest.context"
 
 
@@ -56,9 +58,14 @@ class TempestContextTestCase(test.TestCase):
                                       return_value=True).start()
 
         self.cred = fakes.FakeCredential(**CRED)
-        self.deployment = fakes.FakeDeployment(
-            uuid="fake_deployment", admin=self.cred)
-        cfg = {"verifier": mock.Mock(deployment=self.deployment),
+        p_cred = mock.patch(PATH + ".credential.OpenStackCredential",
+                            return_value=self.cred)
+        p_cred.start()
+        self.addCleanup(p_cred.stop)
+        self.env = mock.Mock(data={"platforms": {"openstack": {
+            "platform_data": {"admin": {}}}}}
+        )
+        cfg = {"verifier": mock.Mock(env=self.env),
                "verification": {"uuid": "uuid"}}
         cfg["verifier"].manager.home_dir = "/p/a/t/h"
         cfg["verifier"].manager.configfile = "/fake/path/to/config"
@@ -67,8 +74,7 @@ class TempestContextTestCase(test.TestCase):
         self.context.conf.add_section("orchestration")
         self.context.conf.add_section("scenario")
 
-    @mock.patch("six.moves.builtins.open", side_effect=mock.mock_open(),
-                create=True)
+    @mock.patch("%s.open" % PATH, side_effect=mock.mock_open(), create=True)
     def test__download_image_from_glance(self, mock_open):
         self.mock_isfile.return_value = False
         img_path = os.path.join(self.context.data_dir, "foo")
@@ -84,7 +90,7 @@ class TempestContextTestCase(test.TestCase):
                                             mock.call("t"),
                                             mock.call("a")])
 
-    @mock.patch("six.moves.builtins.open", side_effect=mock.mock_open())
+    @mock.patch("%s.open" % PATH, side_effect=mock.mock_open())
     @mock.patch("requests.get", return_value=mock.MagicMock(status_code=200))
     def test__download_image_from_url_success(self, mock_get, mock_open):
         self.mock_isfile.return_value = False
@@ -116,9 +122,9 @@ class TempestContextTestCase(test.TestCase):
                           self.context._download_image_from_source,
                           os.path.join(self.context.data_dir, "foo"))
 
-    @mock.patch("rally_openstack.wrappers."
+    @mock.patch("rally_openstack.common.wrappers."
                 "network.NeutronWrapper.create_network")
-    @mock.patch("six.moves.builtins.open", side_effect=mock.mock_open())
+    @mock.patch("%s.open" % PATH, side_effect=mock.mock_open())
     def test_options_configured_manually(
             self, mock_open, mock_neutron_wrapper_create_network):
         self.context.available_services = ["glance", "heat", "nova", "neutron"]
@@ -159,7 +165,7 @@ class TempestContextTestCase(test.TestCase):
         self.assertIn(role3, created_roles)
         self.assertIn(role4, created_roles)
 
-    @mock.patch("rally_openstack.services.image.image.Image")
+    @mock.patch("rally_openstack.common.services.image.image.Image")
     def test__discover_image(self, mock_image):
         client = mock_image.return_value
         client.list_images.return_value = [fakes.FakeImage(name="Foo"),
@@ -168,9 +174,8 @@ class TempestContextTestCase(test.TestCase):
         image = self.context._discover_image()
         self.assertEqual("CirrOS", image.name)
 
-    @mock.patch("six.moves.builtins.open", side_effect=mock.mock_open(),
-                create=True)
-    @mock.patch("rally_openstack.services.image.image.Image")
+    @mock.patch("%s.open" % PATH, side_effect=mock.mock_open(), create=True)
+    @mock.patch("rally_openstack.common.services.image.image.Image")
     @mock.patch("os.path.isfile", return_value=False)
     def test__download_image(self, mock_isfile, mock_image, mock_open):
         img_1 = mock.MagicMock()
@@ -207,7 +212,7 @@ class TempestContextTestCase(test.TestCase):
         result = self.context.conf.get("compute", "flavor_ref")
         self.assertEqual("id1", result)
 
-    @mock.patch("rally_openstack.services.image.image.Image")
+    @mock.patch("rally_openstack.common.services.image.image.Image")
     def test__discover_or_create_image_when_image_exists(self, mock_image):
         client = mock_image.return_value
         client.list_images.return_value = [fakes.FakeImage(name="CirrOS")]
@@ -217,7 +222,7 @@ class TempestContextTestCase(test.TestCase):
         self.assertEqual(0, client.create_image.call_count)
         self.assertEqual(0, len(self.context._created_images))
 
-    @mock.patch("rally_openstack.services.image.image.Image")
+    @mock.patch("rally_openstack.common.services.image.image.Image")
     def test__discover_or_create_image(self, mock_image):
         client = mock_image.return_value
 
@@ -262,17 +267,17 @@ class TempestContextTestCase(test.TestCase):
         client.create_subnet.side_effect = [{"subnet": {"id": "subid1"}}]
         client.list_networks.return_value = {"networks": []}
 
-        network = self.context._create_network_resources()
-        self.assertEqual("nid1", network["id"])
-        self.assertEqual("nid1", self.context._created_networks[0]["id"])
-        self.assertEqual("rid1",
-                         self.context._created_networks[0]["router_id"])
-        self.assertEqual("subid1",
-                         self.context._created_networks[0]["subnets"][0])
+        net_topo = self.context._create_network_resources()
+
+        self.assertEqual("nid1", net_topo["network"]["id"])
+        self.assertEqual("rid1", net_topo["routers"][0]["id"])
+        self.assertEqual("subid1", net_topo["subnets"][0]["id"])
+
+    @mock.patch("%s.neutron.NeutronService.supports_extension" % PATH)
+    def test__create_network_resources_public_network_override(
+            self, mock_supports_extension):
+        mock_supports_extension.return_value = True
 
-    @mock.patch("rally_openstack.wrappers.network.NeutronWrapper.ext_gw_mode_enabled",  # noqa E501
-                new_callable=mock.PropertyMock, return_value=True)
-    def test__create_network_resources_public_network_override(self, mock_ext_gw_mode_enabled):  # noqa E501
         client = self.context.clients.neutron()
         conf = self.context.conf
 
@@ -293,8 +298,8 @@ class TempestContextTestCase(test.TestCase):
         _name, pos, _kwargs = client.create_router.mock_calls[0]
         router = pos[0]["router"]
         external_gateway_info = router["external_gateway_info"]
-        self.assertEqual('my-uuid', external_gateway_info["network_id"])
-        self.assertEqual(True, external_gateway_info["enable_snat"])
+        self.assertEqual("my-uuid", external_gateway_info["network_id"])
+        self.assertTrue(external_gateway_info["enable_snat"])
 
     def test__cleanup_tempest_roles(self):
         self.context._created_roles = [fakes.FakeRole(), fakes.FakeRole()]
@@ -303,7 +308,7 @@ class TempestContextTestCase(test.TestCase):
         client = self.context.clients.keystone()
         self.assertEqual(2, client.roles.delete.call_count)
 
-    @mock.patch("rally_openstack.services.image.image.Image")
+    @mock.patch("rally_openstack.common.services.image.image.Image")
     def test__cleanup_images(self, mock_image):
         self.context._created_images = [fakes.FakeImage(id="id1"),
                                         fakes.FakeImage(id="id2")]
@@ -344,26 +349,27 @@ class TempestContextTestCase(test.TestCase):
         self.assertEqual("", self.context.conf.get("orchestration",
                                                    "instance_type"))
 
-    @mock.patch("rally_openstack.wrappers."
-                "network.NeutronWrapper.delete_network")
-    def test__cleanup_network_resources(
-            self, mock_neutron_wrapper_delete_network):
-        self.context._created_networks = [{"name": "net-12345"}]
+    @mock.patch("%s.neutron.NeutronService.delete_network_topology" % PATH)
+    def test__cleanup_network_resources(self, mock_delete_network_topology):
+        self.context._created_networks = [{"network": {"name": "net-12345"}}]
         self.context.conf.set("compute", "fixed_network_name", "net-12345")
 
         self.context._cleanup_network_resources()
-        self.assertEqual(1, mock_neutron_wrapper_delete_network.call_count)
+
+        mock_delete_network_topology.assert_called_once_with(
+            self.context._created_networks[0]
+        )
         self.assertEqual("", self.context.conf.get("compute",
                                                    "fixed_network_name"))
 
-    @mock.patch("six.moves.builtins.open", side_effect=mock.mock_open())
+    @mock.patch("%s.open" % PATH, side_effect=mock.mock_open())
     @mock.patch("%s.TempestContext._configure_option" % PATH)
     @mock.patch("%s.TempestContext._create_tempest_roles" % PATH)
     @mock.patch("rally.verification.utils.create_dir")
     def test_setup(self, mock_create_dir,
                    mock__create_tempest_roles, mock__configure_option,
                    mock_open):
-        verifier = mock.Mock(deployment=self.deployment)
+        verifier = mock.Mock(env=self.env)
         verifier.manager.home_dir = "/p/a/t/h"
 
         # case #1: no neutron and heat
@@ -418,27 +424,28 @@ class TempestContextTestCase(test.TestCase):
         mock__create_tempest_roles.assert_called_once_with()
         mock_open.assert_called_once_with(verifier.manager.configfile, "w")
         ctx.conf.write(mock_open.side_effect())
-        self.assertEqual(
-            [mock.call("DEFAULT", "log_file", "/p/a/t/h/tempest.log"),
-             mock.call("oslo_concurrency", "lock_path", "/p/a/t/h/lock_files"),
-             mock.call("scenario", "img_dir", "/p/a/t/h"),
-             mock.call("scenario", "img_file", ctx.image_name,
-                       helper_method=ctx._download_image),
-             mock.call("compute", "image_ref",
-                       helper_method=ctx._discover_or_create_image),
-             mock.call("compute", "image_ref_alt",
-                       helper_method=ctx._discover_or_create_image),
-             mock.call("compute", "flavor_ref",
-                       helper_method=ctx._discover_or_create_flavor,
-                       flv_ram=config.CONF.openstack.flavor_ref_ram,
-                       flv_disk=config.CONF.openstack.flavor_ref_disk),
-             mock.call("compute", "flavor_ref_alt",
-                       helper_method=ctx._discover_or_create_flavor,
-                       flv_ram=config.CONF.openstack.flavor_ref_alt_ram,
-                       flv_disk=config.CONF.openstack.flavor_ref_alt_disk),
-             mock.call("compute", "fixed_network_name",
-                       helper_method=ctx._create_network_resources),
-             mock.call("orchestration", "instance_type",
-                       helper_method=ctx._discover_or_create_flavor,
-                       flv_ram=config.CONF.openstack.heat_instance_type_ram)],
-            mock__configure_option.call_args_list)
+        self.assertEqual([
+            mock.call("DEFAULT", "log_file", "/p/a/t/h/tempest.log"),
+            mock.call("oslo_concurrency", "lock_path", "/p/a/t/h/lock_files"),
+            mock.call("scenario", "img_dir", "/p/a/t/h"),
+            mock.call("scenario", "img_file", ctx.image_name,
+                      helper_method=ctx._download_image),
+            mock.call("compute", "image_ref",
+                      helper_method=ctx._discover_or_create_image),
+            mock.call("compute", "image_ref_alt",
+                      helper_method=ctx._discover_or_create_image),
+            mock.call("compute", "flavor_ref",
+                      helper_method=ctx._discover_or_create_flavor,
+                      flv_ram=config.CONF.openstack.flavor_ref_ram,
+                      flv_disk=config.CONF.openstack.flavor_ref_disk),
+            mock.call("compute", "flavor_ref_alt",
+                      helper_method=ctx._discover_or_create_flavor,
+                      flv_ram=config.CONF.openstack.flavor_ref_alt_ram,
+                      flv_disk=config.CONF.openstack.flavor_ref_alt_disk),
+            mock.call("compute", "fixed_network_name",
+                      helper_method=ctx._create_network_resources),
+            mock.call("orchestration", "instance_type",
+                      helper_method=ctx._discover_or_create_flavor,
+                      flv_ram=config.CONF.openstack.heat_instance_type_ram,
+                      flv_disk=config.CONF.openstack.heat_instance_type_disk)
+        ], mock__configure_option.call_args_list)
